CONFIG = {
    'encoding': 'utf-8',  # if ('linux' in sys.platform) else 'iso-8859-1'
    'gis_decimals': 3,
    'exe_path': None
}
